@@ -273,7 +273,7 @@ cd_drive_get_media_type_from_path_full (const char *device, gboolean *is_rewrita
 
 	g_return_val_if_fail (device != NULL, CD_MEDIA_TYPE_ERROR);
 
-	fd = open (device, O_RDONLY|O_EXCL|O_NONBLOCK);
+	fd = open (device, O_RDWR|O_EXCL|O_NONBLOCK);
 	if (fd < 0) {
 		if (errno == EBUSY) {
 			return CD_MEDIA_TYPE_BUSY;
@@ -447,7 +447,7 @@ cd_drive_get_media_size_from_path (const char *device)
 
 	secs = 0;
 
-	fd = open (device, O_RDONLY|O_EXCL|O_NONBLOCK);
+	fd = open (device, O_RDWR|O_EXCL|O_NONBLOCK);
 	if (fd < 0) {
 		if (errno == EBUSY) {
 			return CD_MEDIA_SIZE_BUSY;
@@ -754,7 +754,7 @@ get_cd_scsi_id (const char *dev, int *bus, int *id, int *lun)
 	} m_idlun;
 	
 	devfile = g_strdup_printf ("/dev/%s", dev);
-	fd = open(devfile, O_RDONLY | O_NONBLOCK);
+	fd = open(devfile, O_RDWR | O_NONBLOCK);
 	g_free (devfile);
 
 	/* Avoid problems with Valgrind */
@@ -810,7 +810,7 @@ get_device_max_read_speed (char *device)
 
 	max_speed = -1;
 
-	fd = open (device, O_RDONLY|O_EXCL|O_NONBLOCK);
+	fd = open (device, O_RDWR|O_EXCL|O_NONBLOCK);
 	if (fd < 0) {
 		return -1;
 	}
@@ -832,7 +832,7 @@ get_device_max_write_speed (char *device)
 
 	max_speed = -1;
 
-	fd = open (device, O_RDONLY|O_EXCL|O_NONBLOCK);
+	fd = open (device, O_RDWR|O_EXCL|O_NONBLOCK);
 	if (fd < 0) {
 		return -1;
 	}
@@ -1076,7 +1076,7 @@ linux_scan (gboolean recorder_only)
 
 	if (n_scsi_units > 0) {
 		/* open /dev/sg0 to force loading of the sg module if not loaded yet */
-		fd = open ("/dev/sg0", O_RDONLY);
+		fd = open ("/dev/sg0", O_RDWR);
 		if (fd >= 0) {
 			close (fd);
 		}
@@ -1528,3 +1528,21 @@ cd_drive_new (void)
 	cdrom->priv = g_new0 (CDDrivePriv, 1);
 	return cdrom;
 }
+
+CDDrive *
+cd_drive_copy (CDDrive *drive)
+{
+	CDDrive *cdrom;
+
+	cdrom = cd_drive_new ();
+	cdrom->type = drive->type;
+	cdrom->display_name = g_strdup (drive->display_name);
+	cdrom->max_speed_write = drive->max_speed_write;
+	cdrom->max_speed_read = drive->max_speed_read;
+	cdrom->cdrecord_id = g_strdup (drive->cdrecord_id);
+	cdrom->device = g_strdup (drive->device);
+	cdrom->priv->protocol = drive->priv->protocol;
+	cdrom->priv->udi = g_strdup (drive->priv->udi);
+
+	return cdrom;
+}
