@@ -589,6 +589,9 @@ retry:
 	if (use_joliet) {
 		argv[i++] = "-J";
 	}
+	/* Undocumented -input-charset option */
+	argv[i++] = "-input-charset";
+	argv[i++] = "utf8";
 	argv[i++] = "-q";
 	argv[i++] = "-graft-points";
 	argv[i++] = "-path-list";
